@@ -215,6 +215,60 @@ class Storage:
         else:
             return {'total': sum(subs.values())}
 
+    async def get_stats(self):
+        stats = {'total': 0}
+        async with self.db.execute('SELECT kind, COUNT(*) FROM event GROUP BY kind order by 2 DESC') as cursor:
+            kinds = {}
+            async for kind, count in cursor:
+                kinds[kind] = count
+                stats['total'] += count
+            stats['kinds'] = kinds
+        async with self.db.execute('SELECT COUNT(*) FROM verification') as cursor:
+            row = await cursor.fetchone()
+            stats['num_verified'] = row[0]
+        try:
+            async with self.db.execute('SELECT SUM("pgsize") FROM "dbstat" WHERE name="event"') as cursor:
+                row = await cursor.fetchone()
+                stats['db_size'] = row[0]
+        except sqlite3.OperationalError:
+            pass
+        stats['active_subscriptions'] = (await self.num_subscriptions())['total']
+        return stats
+
+    async def get_identified_pubkey(self, identifier, domain=''):
+        query = 'SELECT pubkey, identifier, relays FROM identity WHERE 1 '
+        pars = []
+        if domain:
+            query += ' AND identifier LIKE ? '
+            pars.append(f'%@{domain}')
+        if identifier:
+            query += ' AND identifier = ?'
+            pars.append(identifier)
+        data = {
+            'names': {},
+            'relays': {}
+        }
+        LOG.debug("Getting identity for ? ?", identifier, domain)
+        async with self.db.execute(query, pars) as cursor:
+            async for pubkey, identifier, relays in cursor:
+                data['names'][identifier.split('@')[0]] = pubkey
+                if relays:
+                    data['relays'][pubkey] = rapidjson.loads(relays)
+
+        return data
+
+    async def set_identified_pubkey(self, identifier, pubkey, relays=None):
+        async with self.db.cursor() as cursor:
+            if not pubkey:
+                pars = [identifier,]
+                await cursor.execute("DELETE FROM identity WHERE identifier = ?", pars)
+            elif not validate_id(pubkey):
+                raise StorageException("invalid public key")
+            else:
+                pars = [identifier, pubkey, rapidjson.dumps(relays or [])]
+                await cursor.execute("INSERT OR REPLACE INTO identity (identifier, pubkey, relays) VALUES (?, ?, ?)", pars)
+            await self.db.commit()
+
 
 class Subscription:
     def __init__(self, db, sub_id, filters:list, queue=None, client_id=None):
@@ -272,7 +326,7 @@ class Subscription:
 
         with catchtime() as t:
             matched = self.check_event(event, self.filters)
-        LOG.info('%s/%s notify match %s %s duration:%.2fms', self.client_id, self.sub_id, event.id, matched, t())
+        LOG.debug('%s/%s notify match %s %s duration:%.2fms', self.client_id, self.sub_id, event.id, matched, t())
         if matched:
             await self.queue.put((self.sub_id, event))
 
@@ -529,6 +583,18 @@ async def migrate(db):
             await db.executemany("insert into verification (id, identifier, metadata_id, verified_at, failed_at) values (?, ?, ?, ?, ?)", data)
             LOG.info("migration: transferred %d verification records", len(data))
 
+    async def migrate_to_5(db):
+        """
+        Create the identity table
+        """
+        await db.execute("""
+            CREATE TABLE IF NOT EXISTS identity (
+                identifier TEXT PRIMARY KEY,
+                pubkey TEXT,
+                relays JSON
+            );
+        """)
+        LOG.info("migration: created identity table")
 
 
     version, lasttime = 0, None
