@@ -27,31 +27,12 @@ class VerificationError(Exception):
 class Verifier:
     VERIFICATION_QUERY = """
         SELECT verification.id, identifier, verified_at, failed_at, created_at FROM verification
-        LEFT JOIN events ON verification.metadata_id = events.id 
-        WHERE events.pubkey = ? ORDER BY events.created_at DESC
-    """
-    BATCH_QUERY = f"""
-        SELECT v.id, identifier, verified_at, pubkey, metadata_id FROM verification as v
-        LEFT JOIN events ON v.metadata_id = events.id
-        WHERE pubkey IS NOT NULL AND
-        (? - verified_at > {Config.verification_expiration})
-        ORDER BY verified_at DESC
+        LEFT JOIN event ON verification.metadata_id = event.id 
+        WHERE event.pubkey = ? ORDER BY event.created_at DESC
     """
     FAILURE_QUERY = "UPDATE verification SET failed_at = strftime('%s', 'now') WHERE id = ?"
     SUCCESS_QUERY = "UPDATE verification SET verified_at = strftime('%s', 'now') WHERE id = ?"
 
-    CREATE_TABLE = """
-        CREATE TABLE IF NOT EXISTS verification (
-            id INTEGER PRIMARY KEY,
-            identifier TEXT,
-            metadata_id TEXT,
-            verified_at TIMESTAMP DEFAULT 0,
-            failed_at TIMESTAMP DEFAULT 0
-        );
-        CREATE INDEX if not exists identifieridx on verification (identifier);
-        CREATE INDEX if not exists verifiedidx on verification (verified_at);
-        CREATE INDEX if not exists metadataidx on verification (metadata_id);
-    """.split(';')
 
     def __init__(self):
         self.running = True
@@ -72,7 +53,7 @@ class Verifier:
                 # queue this identifier as a candidate
                 domain = identifier.split('@', 1)[1].lower()
                 if self.check_allowed_domains(domain):
-                    await self.queue.put([None, identifier, 0, event.pubkey, event.id])
+                    await self.queue.put([None, identifier, 0, event.pubkey, event.id_bytes])
                     return True
                 else:
                     LOG.error("Illegal domain in identifier %s", identifier)
@@ -135,7 +116,7 @@ class Verifier:
         return True
 
     async def verification_task(self, db):
-        LOG.info("Starting verification task")
+        LOG.info("Starting verification task. Interval %s", Config.verification_update_frequency)
         last_run = 0
         while self.running:
             candidate = await self.queue.get()
@@ -145,16 +126,22 @@ class Verifier:
             candidates = []
             try:
                 if (time.time() - last_run) > Config.verification_update_frequency:
+                    LOG.debug("running batch query")
                     async with db.cursor() as cursor:
                         try:
-                            await cursor.execute(self.BATCH_QUERY, (int(time.time()), ))
+                            await cursor.execute(f"""
+                                SELECT v.id, identifier, verified_at, pubkey, metadata_id FROM verification as v
+                                LEFT JOIN event ON v.metadata_id = event.id
+                                WHERE pubkey IS NOT NULL AND
+                                (? - verified_at > {Config.verification_expiration})
+                                ORDER BY verified_at DESC
+                            """, (int(time.time()), ))
                         except Exception:
-                            LOG.exception('batch query %s', self.BATCH_QUERY)
+                            LOG.exception('batch query')
                             continue
                         async for row in cursor:
                             candidates.append(row)
                             # vid, identifier, verified_at, pubkey = row
-
             except Exception:
                 LOG.exception("batch_query")
                 continue
@@ -188,7 +175,7 @@ class Verifier:
     async def process_verifications(self, candidates):
         success = []
         failure = []
-        async with aiohttp.ClientSession() as session:
+        async with aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=10.0), json_serialize=rapidjson.dumps) as session:
 
             for vid, identifier, verified_at, pubkey, metadata_id in candidates:
                 LOG.info("Checking verification for %s. Last verified %d", identifier, verified_at)
@@ -204,7 +191,7 @@ class Verifier:
 
                 try:
                     async with session.get(url) as response:
-                        data = await response.json()
+                        data = await response.json(loads=rapidjson.loads)
                     names = data['names']
                 except Exception:
                     LOG.exception("Failure verifying %s from %s", identifier, url)
